﻿using Syncfusion.SfDataGrid.XForms;
using System;
using System.Collections.Generic;
using System.Linq;
using Xamarin.Forms;

namespace ConverterDemo
{
    public class App : Application
    {
        SfDataGrid sfGrid;
        ViewModel vm;
        public static List<object[]> GridValuesList = null;

        public App()
        {
            sfGrid = new SfDataGrid();
            vm = new ViewModel();

            sfGrid.ItemsSource = vm.Collection;
            sfGrid.ColumnSizer = ColumnSizer.None;
          //  sfGrid.AlternationCount = 2;
           // sfGrid.GridStyle.AlternatingRowColor = Color.Blue;

            sfGrid.AutoGenerateColumns = false;
            sfGrid.AllowSorting = true;

            sfGrid.GridViewCreated += SfGrid_GridViewCreated;

            foreach (KeyValuePair<string, string> key in vm.List[0])
            {
                GridTextColumn col = new GridTextColumn();
                col.MappingName = "Val[" + key.Key + "]";
                col.Width = 120d;
                col.DisplayBinding = new Binding("Val[" + key.Key + "]", BindingMode.OneWay, new Converters.GridCurrencyConverter());

                Style style = new Style(typeof(GridCell));
                style.Setters.Add(new Setter() { Property = GridCell.BackgroundColorProperty, Value = new Binding() { Path = col.MappingName, Converter = new Converters.GridCellBackgroundConverter(), ConverterParameter = col.HeaderText } });
                col.CellStyle = style;

                sfGrid.Columns.Add(col);
            }

            MainPage = new ContentPage() { Content = sfGrid };
        }

        private void SfGrid_GridViewCreated(object sender, GridViewCreatedEventArgs e)
        {
            SfDataGrid dg = (SfDataGrid)sender;
            //get the max items and min items from Grid for each column
            if (App.GridValuesList == null) App.GridValuesList = GetColumnValues(dg);
        }

        //get highest or lowest value for each column
        public static List<object[]> GetColumnValues(Syncfusion.SfDataGrid.XForms.SfDataGrid dg)
        {
            try
            {
                //create List<int[]> to hold column and cell position
                List<object[]> list = new List<object[]>();

                if (null == dg.View.Records) return null;


                //create string[] for columns that should be skipped
                //string[] columns = dg.Columns.Where<GridColumn>(s => !IsHighlightSkipColumn(s.HeaderText.ToString())).Select<GridColumn, string>(s => s.HeaderText.ToString()).ToArray<string>();
                string[] columns = dg.Columns.Select<GridColumn, string>(s => s.HeaderText.ToString()).ToArray<string>();

                for (int i = 0; i < columns.Length; i++)
                {
                    //create int[] for column and cell position, set default value for val
                    int[] arr = new int[2];
                    //  decimal val = (getMax) ? 0 : 99999999999;
                    Dictionary<int[], decimal> values = new Dictionary<int[], decimal>();

                    int col = -1;

                    foreach (var column in dg.Columns)
                    {
                        decimal maxVal = -99999999999;
                        decimal minVal = 99999999999;

                        col++;
                        if (column.HeaderText == columns[i])
                        {
                            foreach (var item in dg.View.Records)
                            {
                                var rowData = item.Data;
                                int row = dg.GetRowGenerator().View.Records.IndexOfRecord(rowData);
                               // if (SkipRow(skipRows, dg.GetRowGenerator().View.Records.IndexOfRecord(rowData))) continue;

                                //Get the cell value for each column
                                var cellValue = dg.GetCellValue(rowData, column.MappingName);
                                string text = cellValue.ToString().Replace("€", "").Replace("%", "").Replace(" ", "");

                                //check if text is a decimal value
                                if (IsDecimal(text))
                                {
                                    if (maxVal < Convert.ToDecimal(text))
                                    {
                                        maxVal = Convert.ToDecimal(text);
                                    }

                                    if (minVal > Convert.ToDecimal(text) && Convert.ToDecimal(text) > -1)
                                    {
                                        minVal = Convert.ToDecimal(text);
                                    }
                                }
                            }
                            list.Add(new object[] { column.HeaderText, minVal, maxVal });
                        }
                    }
                }

                return list;
            }
            catch
            {
                return null;
            }
        }        

        //check string is Decimal
        public static bool IsDecimal(string str)
        {
            try
            {
                Convert.ToDecimal(str);
                return true;
            }
            catch
            {
                return false;
            }
        }
    }
}
